v2.2.0
======

Features
--------

- Require Python 3.8 or later.


v2.1.0
======

Require Python 3.6 even though the code only works on 2.7.

Last release.

v2.0.0
======

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

v1.3.1
======

Restored content in the README and corrected changelog.

v1.3.0
======

Project refresh including automated releases of tagged commits.

v1.1.0
======

Added 2to3 build support.

v1.0.0
======

Initial release. Implements NGA geotrans2.
